@@ -211,3 +211,37 @@ config.IntelliSense.traceBeSetted        =
 'Please read [wiki](https://github.com/sumneko/lua-language-server/wiki/IntelliSense-optional-features) to learn more.'
 config.IntelliSense.traceFieldInject     =
 'Please read [wiki](https://github.com/sumneko/lua-language-server/wiki/IntelliSense-optional-features) to learn more.'
+config.diagnostics['unused-local']          =
+'Enable unused local variable diagnostics.'
+config.diagnostics['unused-function']       =
+'Enable unused function diagnostics.'
+config.diagnostics['undefined-global']      =
+'Enable undefined global variable diagnostics.'
+config.diagnostics['global-in-nil-env']     =
+'Enable cannot use global variables （ `_ENV` is set to `nil`） diagnostics.'
+config.diagnostics['unused-label']          =
+'Enable unused label diagnostics.'
+config.diagnostics['unused-vararg']         =
+'Enable unused vararg diagnostics.'
+config.diagnostics['trailing-space']        =
+'Enable trailing space diagnostics.'
+config.diagnostics['redefined-local']       =
+'Enable redefined local variable diagnostics.'
+config.diagnostics['newline-call']          =
+'Enable newline call diagnostics. Is\'s raised when a line starting with `(` is encountered, which is syntactically parsed as a function call on the previous line.'
+config.diagnostics['newfield-call']         = -- TODO: need translate!
+'在字面量表中，2行代码之间缺少分隔符，在语法上被解析为了一次索引操作'
+config.diagnostics['redundant-parameter']   =
+'Enable redundant function parameter diagnostics.'
+config.diagnostics['ambiguity-1']           =
+'Enable ambiguous operator precedence diagnostics. For example, the `num or 0 + 1` expression will be suggested `(num or 0) + 1` instead.'
+config.diagnostics['lowercase-global']      =
+'Enable lowercase global variable definition diagnostics.'
+config.diagnostics['undefined-env-child']   =
+'Enable undefined environment variable diagnostics. It\'s raised when `_ENV` table is set to a new literal table, but the used global variable is no longer present in the global environment.'
+config.diagnostics['duplicate-index']       =
+'Enable duplicate table index diagnostics.'
+config.diagnostics['empty-block']           =
+'Enable empty code block diagnostics.'
+config.diagnostics['redundant-value']       =
+'Enable the redundant values assigned diagnostics. It\'s raised during assignment operation, when the number of values is higher than the number of objects being assigned.'
