@@ -16,12 +16,8 @@ local rpath        = require 'workspace.require-path'
 local lang         = require 'language'
 local lookBackward = require 'core.look-backward'
 local guide        = require 'parser.guide'
-local infer        = require 'vm.infer'
 local await        = require 'await'
 local postfix      = require 'core.completion.postfix'
-local globalMgr    = require 'vm.global-manager'
-local compiler     = require 'vm.compiler'
-local nodeMgr      = require 'vm.node'
 
 local diagnosticModes = {
     'disable-next-line',
@@ -188,11 +184,8 @@ local function buildFunctionSnip(source, value, oop)
 end
 
 local function buildDetail(source)
-    if source.type == 'dummy' then
-        return
-    end
-    local types = infer.getInfer(source):view()
-    local literals = infer.getInfer(source):viewLiterals()
+    local types = vm.getInfer(source):view()
+    local literals = vm.getInfer(source):viewLiterals()
     if literals then
         return types .. ' = ' .. literals
     else
@@ -230,9 +223,6 @@ end
 
 ---@async
 local function buildDesc(source)
-    if source.type == 'dummy' then
-        return
-    end
     local desc = markdown()
     local hover = getHover.get(source)
     desc:add('md', hover)
@@ -312,8 +302,23 @@ local function checkLocal(state, word, position, results)
         if name:sub(1, 1) == '@' then
             goto CONTINUE
         end
-        if infer.getInfer(source):hasFunction() then
-            for _, def in ipairs(vm.getDefs(source)) do
+        if vm.getInfer(source):hasFunction() then
+            local defs = vm.getDefs(source)
+            -- make sure `function` is before `doc.type.function`
+            local orders = {}
+            for i, def in ipairs(defs) do
+                if def.type == 'function' then
+                    orders[def] = i - 20000
+                elseif def.type == 'doc.type.function' then
+                    orders[def] = i - 10000
+                else
+                    orders[def] = i
+                end
+            end
+            table.sort(defs, function (a, b)
+                return orders[a] < orders[b]
+            end)
+            for _, def in ipairs(defs) do
                 if def.type == 'function'
                 or def.type == 'doc.type.function' then
                     local funcLabel = name .. getParams(def, false)
@@ -360,7 +365,7 @@ local function checkModule(state, word, position, results)
         local fileName = path:match '[^/\\]*$'
         local stemName = fileName:gsub('%..+', '')
         if  not locals[stemName]
-        and not globalMgr.hasGlobalSets(state.uri, 'variable', stemName)
+        and not vm.hasGlobalSets(state.uri, 'variable', stemName)
         and not config.get(state.uri, 'Lua.diagnostics.globals')[stemName]
         and stemName:match '^[%a_][%w_]*$'
         and matchKey(word, stemName) then
@@ -382,7 +387,7 @@ local function checkModule(state, word, position, results)
                 goto CONTINUE
             end
             if  targetSource.type == 'getlocal'
-            and vm.isDeprecated(targetSource.node) then
+            and vm.getDeprecated(targetSource.node) then
                 goto CONTINUE
             end
             results[#results+1] = {
@@ -497,7 +502,7 @@ local function checkFieldThen(state, name, src, word, startPos, position, parent
             kind       = kind,
             match      = name:match '^[^(]+',
             insertText = name:match '^[^(]+',
-            deprecated = vm.isDeprecated(src) or nil,
+            deprecated = vm.getDeprecated(src) and true or nil,
             id         = stack(function () ---@async
                 return {
                     detail      = buildDetail(src),
@@ -507,7 +512,7 @@ local function checkFieldThen(state, name, src, word, startPos, position, parent
         })
         return
     end
-    if oop and not infer.getInfer(src):hasFunction() then
+    if oop and not vm.getInfer(src):hasFunction() then
         return
     end
     local literal = guide.getLiteral(value)
@@ -528,7 +533,7 @@ local function checkFieldThen(state, name, src, word, startPos, position, parent
     results[#results+1] = {
         label      = name,
         kind       = kind,
-        deprecated = vm.isDeprecated(src) or nil,
+        deprecated = vm.getDeprecated(src) and true or nil,
         textEdit   = textEdit,
         id         = stack(function () ---@async
             return {
@@ -590,7 +595,7 @@ local function checkFieldOfRefs(refs, state, word, startPos, position, parent, o
             count = count + 1
             goto CONTINUE
         end
-        if vm.isDeprecated(src) then
+        if vm.getDeprecated(src) then
             goto CONTINUE
         end
         if guide.isSet(src) then
@@ -610,14 +615,14 @@ end
 ---@async
 local function checkGlobal(state, word, startPos, position, parent, oop, results)
     local locals = guide.getVisibleLocals(state.ast, position)
-    local globals = globalMgr.getGlobalSets(state.uri, 'variable')
+    local globals = vm.getGlobalSets(state.uri, 'variable')
     checkFieldOfRefs(globals, state, word, startPos, position, parent, oop, results, locals, 'global')
 end
 
 ---@async
 local function checkField(state, word, start, position, parent, oop, results)
     if parent.tag == '_ENV' or parent.special == '_G' then
-        local globals = globalMgr.getGlobalSets(state.uri, 'variable')
+        local globals = vm.getGlobalSets(state.uri, 'variable')
         checkFieldOfRefs(globals, state, word, start, position, parent, oop, results)
     else
         local refs = vm.getFields(parent)
@@ -1123,9 +1128,10 @@ local function checkTypingEnum(state, position, defs, str, results)
     local enums = {}
     for _, def in ipairs(defs) do
         if def.type == 'doc.type.string'
-        or def.type == 'doc.type.integer' then
+        or def.type == 'doc.type.integer'
+        or def.type == 'doc.type.boolean' then
             enums[#enums+1] = {
-                label       = util.viewLiteral(def[1]),
+                label       = vm.viewObject(def),
                 description = def.comment and def.comment.text,
                 kind        = define.CompletionItemKind.EnumMember,
             }
@@ -1404,14 +1410,17 @@ local function tryCallArg(state, position, results)
     if arg and arg.type == 'function' then
         return
     end
-    local node = compiler.compileCallArg({ type = 'dummyarg' }, call, argIndex)
+    local node = vm.compileCallArg({ type = 'dummyarg' }, call, argIndex)
+    if not node then
+        return
+    end
     local enums = {}
-    for src in nodeMgr.eachNode(node) do
+    for src in node:eachObject() do
         if src.type == 'doc.type.string'
         or src.type == 'doc.type.integer'
         or src.type == 'doc.type.boolean' then
             enums[#enums+1] = {
-                label       = util.viewLiteral(src[1]),
+                label       = vm.viewObject(src),
                 description = src.comment,
                 kind        = define.CompletionItemKind.EnumMember,
             }
@@ -1430,7 +1439,7 @@ local function tryCallArg(state, position, results)
                     : string()
             end
             enums[#enums+1] = {
-                label       = infer.getInfer(src):view(),
+                label       = vm.getInfer(src):view(),
                 description = description,
                 kind        = define.CompletionItemKind.Function,
                 insertText  = insertText,
@@ -1518,6 +1527,7 @@ local function tryluaDocCate(word, results)
         'module',
         'async',
         'nodiscard',
+        'cast',
     } do
         if matchKey(word, docType) then
             results[#results+1] = {
@@ -1666,8 +1676,27 @@ local function tryluaDocBySource(state, position, source, results)
                 }
             end
         end
+        return true
     elseif source.type == 'doc.module' then
         collectRequireNames('require', state.uri, source.module or '', source, source.smark, position, results)
+        return true
+    elseif source.type == 'doc.cast.name' then
+        local locals = guide.getVisibleLocals(state.ast, position)
+        for name, loc in util.sortPairs(locals) do
+            if matchKey(source[1], name) then
+                results[#results+1] = {
+                    label = name,
+                    kind   = define.CompletionItemKind.Variable,
+                    id     = stack(function () ---@async
+                        return {
+                            detail      = buildDetail(loc),
+                            description = buildDesc(loc),
+                        }
+                    end),
+                }
+            end
+        end
+        return true
     end
     return false
 end
@@ -1723,7 +1752,7 @@ local function tryluaDocByErr(state, position, err, docState, results)
         local label = {}
         local insertText = {}
         for i, arg in ipairs(func.args) do
-            if arg[1] and not arg.dummy then
+            if arg[1] and arg.type ~= 'self' then
                 label[#label+1] = arg[1]
                 if #label == 1 then
                     insertText[#insertText+1] = ('%s ${%d:any}'):format(arg[1], #label)
@@ -1762,6 +1791,22 @@ local function tryluaDocByErr(state, position, err, docState, results)
         end
     elseif err.type == 'LUADOC_MISS_MODULE_NAME' then
         collectRequireNames('require', state.uri, '', docState, nil, position, results)
+    elseif err.type == 'LUADOC_MISS_LOCAL_NAME' then
+        local locals = guide.getVisibleLocals(state.ast, position)
+        for name, loc in util.sortPairs(locals) do
+            if name ~= '_ENV' then
+                results[#results+1] = {
+                    label = name,
+                    kind   = define.CompletionItemKind.Variable,
+                    id     = stack(function () ---@async
+                        return {
+                            detail      = buildDetail(loc),
+                            description = buildDesc(loc),
+                        }
+                    end),
+                }
+            end
+        end
     end
 end
 
@@ -1773,21 +1818,21 @@ local function buildluaDocOfFunction(func)
     local returns = {}
     if func.args then
         for _, arg in ipairs(func.args) do
-            args[#args+1] = infer.getInfer(arg):view()
+            args[#args+1] = vm.getInfer(arg):view()
         end
     end
     if func.returns then
         for _, rtns in ipairs(func.returns) do
             for n = 1, #rtns do
                 if not returns[n] then
-                    returns[n] = infer.getInfer(rtns[n]):view()
+                    returns[n] = vm.getInfer(rtns[n]):view()
                 end
             end
         end
     end
     for n, arg in ipairs(args) do
         local funcArg = func.args[n]
-        if funcArg[1] and not funcArg.dummy then
+        if funcArg[1] and funcArg.type ~= 'self' then
             index = index + 1
             buf[#buf+1] = ('---@param %s ${%d:%s}'):format(
                 funcArg[1],
@@ -1880,6 +1925,9 @@ local function tryComment(state, position, results)
     local doc  = getluaDoc(state, position)
     if not word then
         local comment = getComment(state, position)
+        if not comment then
+            return
+        end
         if comment.type == 'comment.short'
         or comment.type == 'comment.cshort' then
             if comment.text == '' then
@@ -1935,6 +1983,8 @@ local function completion(uri, position, triggerCharacter)
         return nil
     end
     clearStack()
+    vm.lockCache()
+    local _ <close> = vm.unlockCache
     local results = {}
     tracy.ZoneBeginN 'completion #2'
     tryCompletions(state, position, triggerCharacter, results)
