@@ -53,6 +53,7 @@ local accept = {
     ['doc.alias.name']   = true,
     ['doc.see.name']     = true,
     ['doc.see.field']    = true,
+    ['doc.cast.name']    = true,
 }
 
 local function checkRequire(source, offset)
@@ -133,13 +134,16 @@ return function (uri, offset)
     local defs = vm.getDefs(source)
 
     for _, src in ipairs(defs) do
-        if src.dummy then
+        if src.type == 'global' then
             goto CONTINUE
         end
         local root = guide.getRoot(src)
         if not root then
             goto CONTINUE
         end
+        if src.type == 'self' then
+            goto CONTINUE
+        end
         src = src.field or src.method or src
         if src.type == 'getindex'
         or src.type == 'setindex'
