@@ -1,6 +1,4 @@
-local infer    = require 'vm.infer'
-local guide    = require 'parser.guide'
-local compiler = require 'vm.compiler'
+local vm       = require 'vm.vm'
 
 ---@param source parser.object
 ---@return integer
@@ -62,13 +60,12 @@ local function asFunction(source)
     local returns = {}
 
     for i = 1, num do
-        local rtn  = compiler.getReturnOfFunction(source, i)
+        local rtn  = vm.getReturnOfFunction(source, i)
         local doc  = docs[i]
         local name = doc and doc.name and doc.name[1] and (doc.name[1] .. ': ')
-        local text = ('%s%s%s'):format(
+        local text = ('%s%s'):format(
             name or '',
-            infer.getInfer(rtn):view(),
-            doc and doc.optional and '?' or ''
+            vm.getInfer(rtn):view()
         )
         if i == 1 then
             returns[i] = ('  -> %s'):format(text)
@@ -86,10 +83,7 @@ local function asDocFunction(source)
     end
     local returns = {}
     for i, rtn in ipairs(source.returns) do
-        local rtnText = ('%s%s'):format(
-            infer.getInfer(rtn):view(),
-            rtn.optional and '?' or ''
-        )
+        local rtnText = vm.getInfer(rtn):view()
         if i == 1 then
             returns[#returns+1] = ('  -> %s'):format(rtnText)
         else
