@@ -2,7 +2,6 @@ local guide   = require 'parser.guide'
 local files   = require 'files'
 local encoder = require 'encoder'
 
--- TODO
 local offsetEncoding = 'utf16'
 
 local m = {}
@@ -178,4 +177,8 @@ function m.textEdit(range, newtext)
     }
 end
 
+function m.setOffsetEncoding(encoding)
+    offsetEncoding = encoding:lower():gsub('%-', '')
+end
+
 return m
