@@ -9,10 +9,10 @@ m.DiagnosticSeverity = {
 }
 
 ---@alias DiagnosticDefaultSeverity
----| '"Hint"'
----| '"Information"'
----| '"Warning"'
----| '"Error"'
+---| 'Hint'
+---| 'Information'
+---| 'Warning'
+---| 'Error'
 
 --- 诊断类型与默认等级
 ---@type table<string, DiagnosticDefaultSeverity>
@@ -29,6 +29,7 @@ m.DiagnosticDefaultSeverity = {
     ['newline-call']            = 'Information',
     ['newfield-call']           = 'Warning',
     ['redundant-parameter']     = 'Warning',
+    ['missing-parameter']       = 'Warning',
     ['redundant-return']        = 'Warning',
     ['ambiguity-1']             = 'Warning',
     ['lowercase-global']        = 'Information',
@@ -41,15 +42,16 @@ m.DiagnosticDefaultSeverity = {
     ['unbalanced-assignments']  = 'Warning',
     ['close-non-object']        = 'Warning',
     ['count-down-loop']         = 'Warning',
-    ['no-implicit-any']         = 'Information',
+    ['no-unknown']              = 'Information',
     ['deprecated']              = 'Warning',
     ['different-requires']      = 'Warning',
     ['await-in-sync']           = 'Warning',
     ['not-yieldable']           = 'Warning',
     ['discard-returns']         = 'Warning',
+    ['need-check-nil']          = 'Warning',
     ['type-check']              = 'Warning',
 
-    ['duplicate-doc-class']     = 'Warning',
+    ['duplicate-doc-alias']     = 'Warning',
     ['undefined-doc-class']     = 'Warning',
     ['undefined-doc-name']      = 'Warning',
     ['circle-doc-class']        = 'Warning',
@@ -57,15 +59,15 @@ m.DiagnosticDefaultSeverity = {
     ['duplicate-doc-param']     = 'Warning',
     ['doc-field-no-class']      = 'Warning',
     ['duplicate-doc-field']     = 'Warning',
-    ['unknown-diag-code']       = 'Waiting',
+    ['unknown-diag-code']       = 'Warning',
 
     ['codestyle-check']         = "Warning",
 }
 
 ---@alias DiagnosticDefaultNeededFileStatus
----| '"Any"'
----| '"Opened"'
----| '"None"'
+---| 'Any'
+---| 'Opened'
+---| 'None'
 
 -- 文件状态
 m.FileStatus = {
@@ -88,6 +90,7 @@ m.DiagnosticDefaultNeededFileStatus = {
     ['newline-call']            = 'Any',
     ['newfield-call']           = 'Any',
     ['redundant-parameter']     = 'Opened',
+    ['missing-parameter']       = 'Opened',
     ['redundant-return']        = 'Opened',
     ['ambiguity-1']             = 'Any',
     ['lowercase-global']        = 'Any',
@@ -100,15 +103,16 @@ m.DiagnosticDefaultNeededFileStatus = {
     ['unbalanced-assignments']  = 'Any',
     ['close-non-object']        = 'Any',
     ['count-down-loop']         = 'Any',
-    ['no-implicit-any']         = 'None',
+    ['no-unknown']              = 'None',
     ['deprecated']              = 'Opened',
     ['different-requires']      = 'Any',
     ['await-in-sync']           = 'None',
     ['not-yieldable']           = 'None',
     ['discard-returns']         = 'Opened',
+    ['need-check-nil']          = 'Opened',
     ['type-check']              = 'None',
 
-    ['duplicate-doc-class']     = 'Any',
+    ['duplicate-doc-alias']     = 'Any',
     ['undefined-doc-class']     = 'Any',
     ['undefined-doc-name']      = 'Any',
     ['circle-doc-class']        = 'Any',
@@ -276,21 +280,6 @@ m.BuiltIn = {
     ['utf8']      = 'default',
 }
 
-m.BuiltinType = {
-    ['unknown']       = true,
-    ['any']           = true,
-    ['nil']           = true,
-    ['boolean']       = true,
-    ['number']        = true,
-    ['integer']       = true,
-    ['thread']        = true,
-    ['table']         = true,
-    ['string']        = true,
-    ['userdata']      = true,
-    ['lightuserdata'] = true,
-    ['function']      = true,
-}
-
 m.InlayHintKind = {
     Other     = 0,
     Type      = 1,
